@@ -260,7 +260,7 @@ class BlanketAgreement(Workflow, ModelSQL, ModelView):
         company = pattern.get('company')
         if not company:
             company = cls.default_company()
-        if company:
+        if company is not None and company >= 0:
             return Company(company).currency.id
 
     @fields.depends('company', 'customer', 'lines')
